@@ -138,8 +138,8 @@ betweenness <- function(graph, v = V(graph), directed = TRUE, weights = NULL,
   if (!missing(nobigint)) {
     warning("'nobigint' is deprecated since igraph 1.3 and will be removed in igraph 1.4")
   }
-  on.exit(.Call(C_R_igraph_finalizer))
-  res <- .Call(C_R_igraph_betweenness_cutoff, graph, v - 1, directed, weights, cutoff)
+  on.exit(.Call(R_igraph_finalizer))
+  res <- .Call(R_igraph_betweenness_cutoff, graph, v - 1, directed, weights, cutoff)
   if (normalized) {
     vc <- as.numeric(vcount(graph))
     if (is_directed(graph) && directed) {
@@ -180,9 +180,9 @@ edge_betweenness <- function(graph, e = E(graph),
     cutoff <- -1
   }
 
-  on.exit(.Call(C_R_igraph_finalizer))
+  on.exit(.Call(R_igraph_finalizer))
   # Function call
-  res <- .Call(C_R_igraph_edge_betweenness_cutoff, graph, directed, weights, cutoff)
+  res <- .Call(R_igraph_edge_betweenness_cutoff, graph, directed, weights, cutoff)
   res[as.numeric(e)]
 }
 
@@ -287,9 +287,9 @@ closeness <- function(graph, vids = V(graph),
     cutoff <- -1
   }
 
-  on.exit(.Call(C_R_igraph_finalizer))
+  on.exit(.Call(R_igraph_finalizer))
   # Function call
-  res <- .Call(C_R_igraph_closeness_cutoff, graph, vids - 1, mode, weights, normalized, cutoff)$res
+  res <- .Call(R_igraph_closeness_cutoff, graph, vids - 1, mode, weights, normalized, cutoff)$res
   if (igraph_opt("add.vertex.names") && is_named(graph)) {
     names(res) <- V(graph)$name[vids]
   }
@@ -303,7 +303,7 @@ estimate_closeness <- function(graph, vids = V(graph), mode = c("out", "in", "al
 }
 
 #' @rdname arpack
-#' @family centrality
+#' @family arpack
 #' @export
 arpack_defaults <- list(
   bmat = "I", n = 0, which = "XX", nev = 1, tol = 0.0,
@@ -497,7 +497,7 @@ arpack_defaults <- list(
 #'     which = "LM", maxiter = 2000
 #'   ))
 #' }
-#' @family centrality
+#' @family arpack
 #' @export
 arpack <- function(func, extra = NULL, sym = FALSE, options = arpack_defaults,
                    env = parent.frame(), complex = !sym) {
@@ -526,8 +526,8 @@ arpack <- function(func, extra = NULL, sym = FALSE, options = arpack_defaults,
     warning("Symmetric matrix, setting `complex' to FALSE")
   }
 
-  on.exit(.Call(C_R_igraph_finalizer))
-  res <- .Call(C_R_igraph_arpack, func, extra, options, env, sym)
+  on.exit(.Call(R_igraph_finalizer))
+  res <- .Call(R_igraph_arpack, func, extra, options, env, sym)
 
   if (complex) {
     rew <- arpack.unpack.complex(
@@ -562,9 +562,9 @@ arpack.unpack.complex <- function(vectors, values, nev) {
   values <- as.matrix(structure(as.double(values), dim = dim(values)))
   nev <- as.integer(nev)
 
-  on.exit(.Call(C_R_igraph_finalizer))
+  on.exit(.Call(R_igraph_finalizer))
   # Function call
-  res <- .Call(C_R_igraph_arpack_unpack_complex, vectors, values, nev)
+  res <- .Call(R_igraph_arpack_unpack_complex, vectors, values, nev)
 
   res
 }
@@ -679,13 +679,15 @@ subgraph_centrality <- function(graph, diag = FALSE) {
 #'
 #' @family centrality
 #' @export
-spectrum <- spectrum
+spectrum <- eigen_adjacency_impl
 
-eigen_defaults <- list(
-  pos = "LM", howmany = 1L, il = -1L, iu = -1L,
-  vl = -Inf, vu = Inf, vestimate = 0L,
-  balance = "none"
-)
+eigen_defaults <- function() {
+  list(
+    pos = "LM", howmany = 1L, il = -1L, iu = -1L,
+    vl = -Inf, vu = Inf, vestimate = 0L,
+    balance = "none"
+  )
+}
 
 #' Find Eigenvector Centrality Scores of Network Positions
 #'
@@ -772,7 +774,7 @@ eigen_defaults <- list(
 #' eigen_centrality(g)
 #' @family centrality
 #' @export
-eigen_centrality <- eigen_centrality
+eigen_centrality <- eigenvector_centrality_impl
 
 
 #' Strength or weighted vertex degree
@@ -811,7 +813,7 @@ eigen_centrality <- eigen_centrality
 #' strength(g)
 #' @family centrality
 #' @export
-strength <- strength
+strength <- strength_impl
 
 
 #' Graph diversity
@@ -855,18 +857,21 @@ strength <- strength
 #' diversity(g3)
 #' @family centrality
 #' @export
-diversity <- diversity
+diversity <- diversity_impl
 
 
-#' Kleinberg's hub centrality scores.
+#' Kleinberg's hub and authority centrality scores.
 #'
 #' The hub scores of the vertices are defined as the principal eigenvector
 #' of \eqn{A A^T}{A*t(A)}, where \eqn{A} is the adjacency matrix of the
 #' graph.
 #'
+#' Similarly, the authority scores of the vertices are defined as the principal
+#' eigenvector of \eqn{A^T A}{t(A)*A}, where \eqn{A} is the adjacency matrix of
+#' the graph.
+#'
 #' For undirected matrices the adjacency matrix is symmetric and the hub
-#' scores are the same as authority scores, see
-#' [authority_score()].
+#' scores are the same as authority scores.
 #'
 #' @aliases hub.score
 #' @param graph The input graph.
@@ -882,69 +887,21 @@ diversity <- diversity
 #' @param options A named list, to override some ARPACK options. See
 #'   [arpack()] for details.
 #' @return A named list with members:
-#'   \item{vector}{The authority/hub scores of the vertices.}
+#'   \item{vector}{The hub or authority scores of the vertices.}
 #'   \item{value}{The corresponding eigenvalue of the calculated
 #'     principal eigenvector.}
 #'   \item{options}{Some information about the ARPACK computation, it has
 #'     the same members as the `options` member returned
 #'     by [arpack()], see that for documentation.}
-#' @seealso [authority_score()],
-#' [eigen_centrality()] for eigenvector centrality,
+#' @seealso [eigen_centrality()] for eigenvector centrality,
 #' [page_rank()] for the Page Rank scores. [arpack()] for
 #' the underlining machinery of the computation.
 #' @references J. Kleinberg. Authoritative sources in a hyperlinked
 #' environment. *Proc. 9th ACM-SIAM Symposium on Discrete Algorithms*,
 #' 1998. Extended version in *Journal of the ACM* 46(1999). Also appears
 #' as IBM Research Report RJ 10076, May 1997.
-#' @examples
-#' ## An in-star
-#' g <- make_star(10)
-#' hub_score(g)$vector
 #'
-#' ## A ring
-#' g2 <- make_ring(10)
-#' hub_score(g2)$vector
-hub_score <- hub_score
-
-
-#' Kleinberg's authority centrality scores.
-#'
-#' The authority scores of the vertices are defined as the principal
-#' eigenvector of \eqn{A^T A}{t(A)*A}, where \eqn{A} is the adjacency
-#' matrix of the graph.
-#'
-#' For undirected matrices the adjacency matrix is symmetric and the
-#' authority scores are the same as hub scores, see
-#' [hub_score()].
-#'
-#' @aliases authority.score
-#' @param graph The input graph.
-#' @param scale Logical scalar, whether to scale the result to have a maximum
-#'   score of one. If no scaling is used then the result vector has unit length
-#'   in the Euclidean norm.
-#' @param weights Optional positive weight vector for calculating weighted
-#'   scores. If the graph has a `weight` edge attribute, then this is used
-#'   by default.
-#'   This function interprets edge weights as connection strengths. In the
-#'   random surfer model, an edge with a larger weight is more likely to be
-#'   selected by the surfer.
-#' @param options A named list, to override some ARPACK options. See
-#'   [arpack()] for details.
-#' @return A named list with members:
-#'   \item{vector}{The authority/hub scores of the vertices.}
-#'   \item{value}{The corresponding eigenvalue of the calculated
-#'     principal eigenvector.}
-#'   \item{options}{Some information about the ARPACK computation, it has
-#'     the same members as the `options` member returned
-#'     by [arpack()], see that for documentation.}
-#' @seealso [hub_score()], [eigen_centrality()] for
-#' eigenvector centrality, [page_rank()] for the Page Rank
-#' scores. [arpack()] for the underlining machinery of the
-#' computation.
-#' @references J. Kleinberg. Authoritative sources in a hyperlinked
-#' environment. *Proc. 9th ACM-SIAM Symposium on Discrete Algorithms*,
-#' 1998. Extended version in *Journal of the ACM* 46(1999). Also appears
-#' as IBM Research Report RJ 10076, May 1997.
+#' @export
 #' @examples
 #' ## An in-star
 #' g <- make_star(10)
@@ -955,7 +912,16 @@ hub_score <- hub_score
 #' g2 <- make_ring(10)
 #' hub_score(g2)$vector
 #' authority_score(g2)$vector
-authority_score <- authority_score
+#' @family centrality
+hub_score <- hub_score_impl
+
+
+#' @rdname hub_score
+#' @aliases authority.score
+#' @param options A named list, to override some ARPACK options. See
+#'   [arpack()] for details.
+#' @export
+authority_score <- authority_score_impl
 
 
 #' The Page Rank algorithm
@@ -1042,7 +1008,7 @@ authority_score <- authority_score
 #' page_rank(g3, personalized = reset)$vector
 #' @family centrality
 #' @export
-page_rank <- page_rank
+page_rank <- personalized_pagerank_impl
 
 #' Harmonic centrality of vertices
 #'
@@ -1089,7 +1055,7 @@ page_rank <- page_rank
 #' harmonic_centrality(g2, mode = "out")
 #' harmonic_centrality(g %du% make_full_graph(5), mode = "all")
 #'
-harmonic_centrality <- harmonic_centrality
+harmonic_centrality <- harmonic_centrality_cutoff_impl
 
 
 
@@ -1230,10 +1196,10 @@ bonpow.sparse <- function(graph, nodes = V(graph), loops = FALSE,
 #' @examples
 #'
 #' # Generate some test data from Bonacich, 1987:
-#' g.c <- graph(c(1, 2, 1, 3, 2, 4, 3, 5), dir = FALSE)
-#' g.d <- graph(c(1, 2, 1, 3, 1, 4, 2, 5, 3, 6, 4, 7), dir = FALSE)
-#' g.e <- graph(c(1, 2, 1, 3, 1, 4, 2, 5, 2, 6, 3, 7, 3, 8, 4, 9, 4, 10), dir = FALSE)
-#' g.f <- graph(
+#' g.c <- make_graph(c(1, 2, 1, 3, 2, 4, 3, 5), dir = FALSE)
+#' g.d <- make_graph(c(1, 2, 1, 3, 1, 4, 2, 5, 3, 6, 4, 7), dir = FALSE)
+#' g.e <- make_graph(c(1, 2, 1, 3, 1, 4, 2, 5, 2, 6, 3, 7, 3, 8, 4, 9, 4, 10), dir = FALSE)
+#' g.f <- make_graph(
 #'   c(1, 2, 1, 3, 1, 4, 2, 5, 2, 6, 2, 7, 3, 8, 3, 9, 3, 10, 4, 11, 4, 12, 4, 13),
 #'   dir = FALSE
 #' )
@@ -1415,9 +1381,9 @@ alpha.centrality.sparse <- function(graph, nodes = V(graph), alpha = 1,
 #' @examples
 #'
 #' # The examples from Bonacich's paper
-#' g.1 <- graph(c(1, 3, 2, 3, 3, 4, 4, 5))
-#' g.2 <- graph(c(2, 1, 3, 1, 4, 1, 5, 1))
-#' g.3 <- graph(c(1, 2, 2, 3, 3, 4, 4, 1, 5, 1))
+#' g.1 <- make_graph(c(1, 3, 2, 3, 3, 4, 4, 5))
+#' g.2 <- make_graph(c(2, 1, 3, 1, 4, 1, 5, 1))
+#' g.3 <- make_graph(c(1, 2, 2, 3, 3, 4, 4, 1, 5, 1))
 #' alpha_centrality(g.1)
 #' alpha_centrality(g.2)
 #' alpha_centrality(g.3, alpha = 0.5)
