@@ -35,8 +35,8 @@ count_components <- function(graph, mode = c("weak", "strong")) {
     "strong" = 2
   )
 
-  on.exit(.Call(C_R_igraph_finalizer))
-  .Call(C_R_igraph_no_clusters, graph, as.numeric(mode))
+  on.exit(.Call(R_igraph_finalizer))
+  .Call(R_igraph_no_clusters, graph, as.numeric(mode))
 }
 
 #' @rdname components
@@ -115,9 +115,9 @@ decompose <- function(graph, mode = c("weak", "strong"), max.comps = NA,
   if (is.na(max.comps)) {
     max.comps <- -1
   }
-  on.exit(.Call(C_R_igraph_finalizer))
+  on.exit(.Call(R_igraph_finalizer))
   .Call(
-    C_R_igraph_decompose, graph, as.numeric(mode),
+    R_igraph_decompose, graph, as.numeric(mode),
     as.numeric(max.comps), as.numeric(min.vertices)
   )
 }
@@ -160,12 +160,12 @@ decompose <- function(graph, mode = c("weak", "strong"), max.comps = NA,
 #'
 #' @family components
 #' @export
-articulation_points <- articulation_points
+articulation_points <- articulation_points_impl
 
 #' @rdname articulation_points
 #' @family components
 #' @export
-bridges <- bridges
+bridges <- bridges_impl
 
 
 #' Biconnected components
@@ -205,4 +205,4 @@ bridges <- bridges
 #' bc <- biconnected_components(g)
 #' @family components
 #' @export
-biconnected_components <- biconnected_components
+biconnected_components <- biconnected_components_impl
