@@ -123,6 +123,7 @@
 #' as_data_frame(g, what = "vertices")
 #' as_data_frame(g, what = "edges")
 #'
+#' @export
 graph_from_data_frame <- function(d, directed = TRUE, vertices = NULL) {
   d <- as.data.frame(d)
   if (!is.null(vertices)) {
@@ -244,12 +245,12 @@ graph_from_edgelist <- function(el, directed = TRUE) {
       names <- unique(as.character(t(el)))
       ids <- seq(names)
       names(ids) <- names
-      res <- graph(unname(ids[t(el)]), directed = directed)
+      res <- make_graph(unname(ids[t(el)]), directed = directed)
       rm(ids)
       V(res)$name <- names
     } else {
       ## normal edge list
-      res <- graph(t(el), directed = directed)
+      res <- make_graph(t(el), directed = directed)
     }
   }
 
