@@ -74,7 +74,7 @@
 #' min_cut(g, capacity = rep(1, vcount(g)))
 #' min_cut(g, value.only = FALSE, capacity = rep(1, vcount(g)))
 #'
-#' g2 <- graph(c(1, 2, 2, 3, 3, 4, 1, 6, 6, 5, 5, 4, 4, 1))
+#' g2 <- make_graph(c(1, 2, 2, 3, 3, 4, 1, 6, 6, 5, 5, 4, 4, 1))
 #' E(g2)$capacity <- c(3, 1, 2, 10, 1, 3, 2)
 #' min_cut(g2, value.only = FALSE)
 #' @family flow
@@ -103,12 +103,12 @@ min_cut <- function(graph, source = NULL, target = NULL, capacity = NULL, value.
   }
 
   value.only <- as.logical(value.only)
-  on.exit(.Call(C_R_igraph_finalizer))
+  on.exit(.Call(R_igraph_finalizer))
   if (is.null(target) && is.null(source)) {
     if (value.only) {
-      res <- .Call(C_R_igraph_mincut_value, graph, capacity)
+      res <- .Call(R_igraph_mincut_value, graph, capacity)
     } else {
-      res <- .Call(C_R_igraph_mincut, graph, capacity)
+      res <- .Call(R_igraph_mincut, graph, capacity)
       res$cut <- res$cut + 1
       res$partition1 <- res$partition1 + 1
       res$partition2 <- res$partition2 + 1
@@ -122,17 +122,17 @@ min_cut <- function(graph, source = NULL, target = NULL, capacity = NULL, value.
   } else {
     if (value.only) {
       res <- .Call(
-        C_R_igraph_st_mincut_value, graph,
+        R_igraph_st_mincut_value, graph,
         as.igraph.vs(graph, source) - 1,
         as.igraph.vs(graph, target) - 1, capacity
       )
     } else {
       res <- .Call(
-        C_R_igraph_st_mincut, graph,
+        R_igraph_st_mincut, graph,
         as.igraph.vs(graph, source) - 1,
         as.igraph.vs(graph, target) - 1, capacity
       )
-      # No need to add +1 here; C_R_igraph_st_mincut() is autogenerated and
+      # No need to add +1 here; R_igraph_st_mincut() is autogenerated and
       # adds +1 already
       if (igraph_opt("return.vs.es")) {
         res$cut <- create_es(graph, res$cut)
@@ -235,12 +235,12 @@ vertex_connectivity <- function(graph, source = NULL, target = NULL, checks = TR
   }
 
   if (is.null(source) && is.null(target)) {
-    on.exit(.Call(C_R_igraph_finalizer))
-    .Call(C_R_igraph_vertex_connectivity, graph, as.logical(checks))
+    on.exit(.Call(R_igraph_finalizer))
+    .Call(R_igraph_vertex_connectivity, graph, as.logical(checks))
   } else if (!is.null(source) && !is.null(target)) {
-    on.exit(.Call(C_R_igraph_finalizer))
+    on.exit(.Call(R_igraph_finalizer))
     .Call(
-      C_R_igraph_st_vertex_connectivity, graph, as.igraph.vs(graph, source) - 1,
+      R_igraph_st_vertex_connectivity, graph, as.igraph.vs(graph, source) - 1,
       as.igraph.vs(graph, target) - 1
     )
   } else {
@@ -327,12 +327,12 @@ edge_connectivity <- function(graph, source = NULL, target = NULL, checks = TRUE
   }
 
   if (is.null(source) && is.null(target)) {
-    on.exit(.Call(C_R_igraph_finalizer))
-    .Call(C_R_igraph_edge_connectivity, graph, as.logical(checks))
+    on.exit(.Call(R_igraph_finalizer))
+    .Call(R_igraph_edge_connectivity, graph, as.logical(checks))
   } else if (!is.null(source) && !is.null(target)) {
-    on.exit(.Call(C_R_igraph_finalizer))
+    on.exit(.Call(R_igraph_finalizer))
     .Call(
-      C_R_igraph_st_edge_connectivity, graph,
+      R_igraph_st_edge_connectivity, graph,
       as.igraph.vs(graph, source) - 1, as.igraph.vs(graph, target) - 1
     )
   } else {
@@ -354,9 +354,9 @@ edge_disjoint_paths <- function(graph, source, target) {
     target <- NULL
   }
 
-  on.exit(.Call(C_R_igraph_finalizer))
+  on.exit(.Call(R_igraph_finalizer))
   .Call(
-    C_R_igraph_edge_disjoint_paths, graph,
+    R_igraph_edge_disjoint_paths, graph,
     as.igraph.vs(graph, source) - 1, as.igraph.vs(graph, target) - 1
   )
 }
@@ -375,9 +375,9 @@ vertex_disjoint_paths <- function(graph, source = NULL, target = NULL) {
     target <- NULL
   }
 
-  on.exit(.Call(C_R_igraph_finalizer))
+  on.exit(.Call(R_igraph_finalizer))
   .Call(
-    C_R_igraph_vertex_disjoint_paths, graph, as.igraph.vs(graph, source) - 1,
+    R_igraph_vertex_disjoint_paths, graph, as.igraph.vs(graph, source) - 1,
     as.igraph.vs(graph, target) - 1
   )
 }
@@ -389,8 +389,8 @@ adhesion <- function(graph, checks = TRUE) {
     stop("Not a graph object")
   }
 
-  on.exit(.Call(C_R_igraph_finalizer))
-  .Call(C_R_igraph_adhesion, graph, as.logical(checks))
+  on.exit(.Call(R_igraph_finalizer))
+  .Call(R_igraph_adhesion, graph, as.logical(checks))
 }
 
 #' @rdname vertex_connectivity
@@ -402,8 +402,8 @@ cohesion.igraph <- function(x, checks = TRUE, ...) {
     stop("Not a graph object")
   }
 
-  on.exit(.Call(C_R_igraph_finalizer))
-  .Call(C_R_igraph_cohesion, x, as.logical(checks))
+  on.exit(.Call(R_igraph_finalizer))
+  .Call(R_igraph_cohesion, x, as.logical(checks))
 }
 
 #' List all (s,t)-cuts of a graph
@@ -445,7 +445,7 @@ cohesion.igraph <- function(x, checks = TRUE, ...) {
 #' st_cuts(g2, source = "s", target = "t")
 #' @family flow
 #' @export
-st_cuts <- st_cuts
+st_cuts <- all_st_cuts_impl
 
 
 #' List all minimum \eqn{(s,t)}-cuts of a graph
@@ -496,7 +496,7 @@ st_cuts <- st_cuts
 #' st_min_cuts(g, source = "s", target = "t")
 #' @family flow
 #' @export
-st_min_cuts <- st_min_cuts
+st_min_cuts <- all_st_mincuts_impl
 
 
 #' Dominator tree
@@ -569,9 +569,9 @@ dominator_tree <- function(graph, root, mode = c("out", "in", "all", "total")) {
     "total" = 3
   )
 
-  on.exit(.Call(C_R_igraph_finalizer))
+  on.exit(.Call(R_igraph_finalizer))
   # Function call
-  res <- .Call(C_R_igraph_dominator_tree, graph, root - 1, mode)
+  res <- .Call(R_igraph_dominator_tree, graph, root - 1, mode)
   if (igraph_opt("return.vs.es")) {
     res$leftout <- create_vs(graph, res$leftout)
   }
@@ -607,6 +607,7 @@ dominator_tree <- function(graph, root, mode = c("out", "in", "all", "total")) {
 #' Stephan Eidenbenz (editors): *Graph-theoretic concepts in computer
 #' science*, 1665, 167--172, 1999. Springer.
 #' @keywords graphs
+#' @export
 #' @examples
 #'
 #' ring <- make_ring(4)
@@ -614,7 +615,8 @@ dominator_tree <- function(graph, root, mode = c("out", "in", "all", "total")) {
 #'
 #' chvatal <- make_graph("chvatal")
 #' min_st_separators(chvatal)
-min_st_separators <- min_st_separators
+#' @family flow
+min_st_separators <- all_minimal_st_separators_impl
 
 
 #' Maximum flow in a graph
@@ -677,7 +679,7 @@ min_st_separators <- min_st_separators
 #' max_flow(g1, source = V(g1)["1"], target = V(g1)["2"])
 #' @family flow
 #' @export
-max_flow <- max_flow
+max_flow <- maxflow_impl
 
 
 #' Vertex separators
@@ -702,7 +704,7 @@ max_flow <- max_flow
 #'   lists all vertex separator of minimum size.
 #' @family flow
 #' @export
-is_separator <- is_separator
+is_separator <- is_separator_impl
 
 
 #' Minimal vertex separators
@@ -756,7 +758,7 @@ is_separator <- is_separator
 #'
 #' @family flow
 #' @export
-is_min_separator <- is_min_separator
+is_min_separator <- is_minimal_separator_impl
 
 
 #' Minimum size vertex separators
@@ -828,4 +830,4 @@ is_min_separator <- is_min_separator
 #'   John - Gery:Russ:Michael
 #' )
 #' min_separators(camp)
-min_separators <- min_separators
+min_separators <- minimum_size_separators_impl
