@@ -63,9 +63,9 @@ motifs <- function(graph, size = 3, cut.prob = rep(0, size)) {
     )
   }
 
-  on.exit(.Call(C_R_igraph_finalizer))
+  on.exit(.Call(R_igraph_finalizer))
   res <- .Call(
-    C_R_igraph_motifs_randesu, graph, as.integer(size),
+    R_igraph_motifs_randesu, graph, as.integer(size),
     as.numeric(cut.prob)
   )
   res[is.nan(res)] <- NA
@@ -109,9 +109,9 @@ count_motifs <- function(graph, size = 3, cut.prob = rep(0, size)) {
     )
   }
 
-  on.exit(.Call(C_R_igraph_finalizer))
+  on.exit(.Call(R_igraph_finalizer))
   .Call(
-    C_R_igraph_motifs_randesu_no, graph, as.integer(size),
+    R_igraph_motifs_randesu_no, graph, as.integer(size),
     as.numeric(cut.prob)
   )
 }
@@ -160,9 +160,9 @@ sample_motifs <- function(graph, size = 3, cut.prob = rep(0, size),
     )
   }
 
-  on.exit(.Call(C_R_igraph_finalizer))
+  on.exit(.Call(R_igraph_finalizer))
   .Call(
-    C_R_igraph_motifs_randesu_estimate, graph, as.integer(size),
+    R_igraph_motifs_randesu_estimate, graph, as.integer(size),
     as.numeric(cut.prob), as.integer(sample.size), as.numeric(sample)
   )
 }
@@ -195,8 +195,9 @@ sample_motifs <- function(graph, size = 3, cut.prob = rep(0, size),
 #'
 #' g <- sample_pa(100)
 #' dyad_census(g)
+#' @family graph motifs
 #' @export
-dyad_census <- dyad_census
+dyad_census <- dyad_census_impl
 
 
 #' Triad census, subgraphs with three vertices
@@ -236,5 +237,6 @@ dyad_census <- dyad_census
 #'
 #' g <- sample_gnm(15, 45, directed = TRUE)
 #' triad_census(g)
+#' @family motifs
 #' @export
-triad_census <- triad_census
+triad_census <- triad_census_impl
