@@ -9,7 +9,7 @@ solve_LSAP <- function(x, maximum = FALSE) {
   if (nc > nr) x <- rbind(x, matrix(2 * sum(x), nc - nr, nc))
   if (maximum) x <- max(x) - x
   storage.mode(x) <- "double"
-  out <- .Call(C_R_igraph_solve_lsap, x, as.integer(nc)) + 1L
+  out <- .Call(R_igraph_solve_lsap, x, as.integer(nc)) + 1L
   out[seq_len(nr)]
 }
 
