@@ -26,6 +26,7 @@
 #include "igraph_memory.h"
 #include "igraph_random.h"
 
+#include "core/interruption.h"
 #include "linalg/arpack_internal.h"
 
 #include <math.h>
@@ -965,6 +966,8 @@ int igraph_arpack_rssolve(igraph_arpack_function_t *fun, void *extra,
     while (1) {
         igraph_real_t *from, *to;
 
+        IGRAPH_ALLOW_INTERRUPTION();
+
 #ifdef HAVE_GFORTRAN
         igraphdsaupd_(&ido, options->bmat, &options->n, options->which,
                       &options->nev, &options->tol,
@@ -979,6 +982,9 @@ int igraph_arpack_rssolve(igraph_arpack_function_t *fun, void *extra,
                       options->iparam, options->ipntr,
                       workd, workl, &options->lworkl, &options->info);
 #endif
+        /* When there is a non-zero error code in options->info, we expect that
+         * ARPACK requests a termination of the iteration by setting ido=99. */
+        IGRAPH_ASSERT(ido == 99 || options->info == 0);
 
         if (ido == -1 || ido == 1) {
             from = workd + options->ipntr[0] - 1;
@@ -1240,6 +1246,8 @@ int igraph_arpack_rnsolve(igraph_arpack_function_t *fun, void *extra,
     while (1) {
         igraph_real_t *from, *to;
 
+        IGRAPH_ALLOW_INTERRUPTION();
+
 #ifdef HAVE_GFORTRAN
         igraphdnaupd_(&ido, options->bmat, &options->n, options->which,
                       &options->nev, &options->tol,
@@ -1254,6 +1262,9 @@ int igraph_arpack_rnsolve(igraph_arpack_function_t *fun, void *extra,
                       options->iparam, options->ipntr,
                       workd, workl, &options->lworkl, &options->info);
 #endif
+        /* When there is a non-zero error code in options->info, we expect that
+         * ARPACK requests a termination of the iteration by setting ido=99. */
+        IGRAPH_ASSERT(ido == 99 || options->info == 0);
 
         if (ido == -1 || ido == 1) {
             from = workd + options->ipntr[0] - 1;
